/******************************************************************
 * 21440 Driver Header file 
 ******************************************************************/
/*
** INTEL CORPORATION PROPRIETARY INFORMATION
** This software is supplied under the terms of a license agreement or
** nondisclosure agreement with Intel Corporation and may not be copied
** or disclosed except in accordance with the terms of that agreement.
** Copyright (C) 2000 Intel Corporation. All rights Reserved.
*/

#ifndef OCTAL_MAC_DRV_H
#define OCTAL_MAC_DRV_H

/*
 * INCLUDES
 */


#ifdef __KERNEL__	

#define MODVERSIONS

#include <linux/modversions.h>
#include <linux/module.h>	/* writing module */
#include <linux/version.h>
#include <linux/kernel.h>	/* kernel mode code */
#include <linux/fs.h>
#include <linux/miscdevice.h>
#include <linux/init.h>
#include <linux/string.h>
#include <asm/uaccess.h>



/*
 * DEBUGGING UTILITIES (Kernel Level)
 */

#define	DBG_ERR		KERN_ERR
#define	DBG_WARN	KERN_WARNING
#define	DBG_INFO	KERN_INFO
#define	DEFAULT_LVL	DBG_ERR		/* misc */

#ifdef	DRV_DEBUG
#define	DBG_LOG(lvl,str,args...)	\
		printk(lvl##"    "str, ##args)
#else
#define	DBG_LOG(lvl,str,args...)	
#endif

#endif	/* kernel */


/*
 * #DEFINES
 */

#ifndef	OK	
#define	OK	0
#endif

#ifndef	ERROR
#define	ERROR	-1
#endif

/*
 * ERROR CODES
 */


/*
 * REGISTER DEFINES
 */

#define	OCTMAC_NUM_MAC_PORTS	8
#define IS_PORT_OK(p)	(((p>=0)&&(p<=(OCTMAC_NUM_MAC_PORTS-1)))?1:0)

#define	OCTMAC_REG_BASE		0xf0800000
#define	OCTMAC_REG_MAP_SIZE	0x1000
#define	MACTOSA_ADDR_FACTOR	4	/* this should be 1 */

/* this map came in a text file with the code  with some errors.
 * Following is correct map.
 */
#define	CHIP_INT       0x00
#define INT_STT        0x04
#define	INT_EN         0x08
#define	TXMT_STT       0x0c
#define	RECV_STT       0x10
#define	PORT_CTR       0x14
#define	DEV_ID         0x18
#define	REV_ID         0x1c
#define	SER_COM        0x20

#define	FFO_TSHD       0x44
#define	FFO_BUS        0x48
#define	TX_PARAM       0x4c
#define	TX_ERR_MOD     0x50
#define	TX_TSHD_BOFF   0x54
#define	RX_PARAM       0x58
#define	RX_FILT_MOD    0x5c
#define	PAUSE_TIME_LSB 0x60
#define	PAUSE_TIME_MSB 0x64
#define	PKT_MAX_SZ_LSB 0x68
#define	PKT_MAX_SZ_MSB 0x6c
#define	SER_MOD        0x84
#define	LNK_STT        0x88
#define	PHY_ADD_BYTE0  0xa0
#define	PHY_ADD_BYTE1  0xa4
#define	PHY_ADD_BYTE2  0xa8
#define	PHY_ADD_BYTE3  0xac
#define	PHY_ADD_BYTE4  0xb0
#define	PHY_ADD_BYTE5  0xb4
#define	PHY_ADD		   PHY_ADD_BYTE0
#define IPG_LSB        0xc8
#define IPG_MSB        0xcc
#if 0	/* this map is in the manual */
#define	CHIP_INT       0x00
#define INT_STT        0x01
#define	INT_EN         0x02
#define	TXMT_STT       0x03
#define	RECV_STT       0x04
#define	PORT_CTR       0x05
#define	DEV_ID         0x06
#define	REV_ID         0x07
#define	SER_COM        0x08
#define	FFO_TSHD       0x11
#define	FFO_BUS        0x12
#define	TX_PARAM       0x13
#define	TX_ERR_MOD     0x14
#define	TX_TSHD_BOFF   0x15
#define	RX_PARAM       0x16
#define	RX_FILT_MOD    0x17
#define	PAUSE_TIME_LSM 0x18
#define	PAUSE_TIME_MSB 0x19
#define	PKT_MAX_SZ_LSM 0x1a
#define	PKT_MAX_SZ_MSB 0x1b
#define	SER_MOD        0x21
#define	LNK_STT        0x22
#define	PHY_ADD_BYTE0  0x28
#define	PHY_ADD_BYTE1  0x29
#define	PHY_ADD_BYTE2  0x2a
#define	PHY_ADD_BYTE3  0x2b
#define	PHY_ADD_BYTE4  0x2c
#define	PHY_ADD_BYTE5  0x2d
#endif


/* NOTE : on the B0 eval board, only "integer" access 
 * seems to be working to access control registers
 */

#define	OCTAL_MAC_REG_READ(dev,reg)		\
			(*(volatile unsigned int *)((dev)->pRegBase+(reg)) & 0xff )

#define	OCTAL_MAC_REG_WRITE(dev,reg,val)	\
			*(volatile unsigned int *)((dev)->pRegBase+(reg)) = ((val) & 0xff)

#define	SETBITS(dev,reg,bits)				\
			OCTAL_MAC_REG_WRITE(dev,reg,	\
				(OCTAL_MAC_REG_READ(dev,reg) | (bits)))

#define	CLEARBITS(dev,reg,bits)				\
			OCTAL_MAC_REG_WRITE(dev,reg,	\
				OCTAL_MAC_REG_READ(dev,reg) & ~(bits))

#define	ISSET(dev,reg,bits)				\
			OCTAL_MAC_REG_READ(dev,reg) & (bits) ? 1 : 0

#define	BIT0	0x01
#define	BIT1	0x02
#define	BIT2	0x04
#define	BIT3	0x08
#define	BIT4	0x10
#define	BIT5	0x20
#define	BIT6	0x40
#define	BIT7	0x80

/* 
 * FIFO Threshold Values
 */
#define	FFO_TSHD_16		1	
#define	FFO_TSHD_24		2
#define	FFO_TSHD_32		3
#define	FFO_TSHD_40		4
#define	FFO_TSHD_48		5
#define	FFO_TSHD_56		6
#define	FFO_TSHD_64		7
#define	FFO_TSHD_72		8
#define	FFO_TSHD_80		9
#define	FFO_TSHD_88		10
#define	FFO_TSHD_96		11
#define	FFO_TSHD_104	12
#define	FFO_TSHD_112	13
#define	FFO_TSHD_120	14
#define	FFO_TSHD_128	15


#define	IS_SYMMODE(dev)		\
			((OCTAL_MAC_REG_READ(dev,SER_MOD) & BIT0) ? 1 : 0)

#define	START_TX(dev)		\
			SETBITS(dev,PORT_CTR,BIT4)

#define	STOP_TX(dev)		\
			CLEARBITS(dev,PORT_CTR,BIT4)

#define	START_RX(dev)		\
			SETBITS(dev,PORT_CTR,BIT3)

#define	STOP_RX(dev)		\
			CLEARBITS(dev,PORT_CTR,BIT3)

#define	START_TX_RX(dev)	\
			SETBITS(dev,PORT_CTR,BIT3|BIT4)

#define	STOP_TX_RX(dev)		\
			CLEARBITS(dev,PORT_CTR,BIT3|BIT4)

#define	RESET_TX_RX(dev)	\
			{\
			SETBITS(dev,PORT_CTR,BIT2);	\
			DELAY(100);	\
			CLEARBITS(dev,PORT_CTR,BIT2);\
			}
			
#define	RESET_PORT(dev)	\
			{	\
			SETBITS(dev,PORT_CTR,BIT2);	\
			DELAY(100);	\
			CLEARBITS(dev,PORT_CTR,BIT2);\
			}
			
#define	RESET_CONTROL(dev)	\
			{	\
			SETBITS(dev,PORT_CTR,BIT1);	\
			DELAY(100);	\
			CLEARBITS(dev,PORT_CTR,BIT1);\
			}
			

#define	RESET_COUNTERS(dev)	\
			{\
			SETBITS(dev,PORT_CTR,BIT0);	\
			DELAY(100);	\
			CLEARBITS(dev,PORT_CTR,BIT0);\
			}
			

#define	IS_STOPE_SET(dev)	\
			((OCTAL_MAC_REG_READ(dev,INT_STT) & BIT6) ? 1 : 0)

#define	IS_PORT_STOPPED(dev)	\
			(((OCTAL_MAC_REG_READ(dev,PORT_CTR) & (BIT3|BIT4))==0) ||	\
			(OCTAL_MAC_REG_READ(dev,INT_STT) & BIT6) ? 1 : 0)


/*
 * READ STATISTICS COUNTERS
 *
 * Each counter is stored in 'Little Endian' format, i.e., LSB
 * stored in low address and MSB in high address.
 *
 * 	RULES	:
 *	1. Any byte can be read ( read only/ read & clear)
 *	2. If multiple bytes are to be read, start reading from low address
 *		and sequentially. WHY ???
 */
#define	CNTR_BASE	0x200
#define	CNTR_BASE_D	0x100	/* resets upon read from here */

#define	TX_UNI_OK	0x00
#define	TX_MLT_OK	0x04
#define	TX_BRD_OK	0x08
#define	TX_DEFER	0xc
#define	TX_COL		0x10
#define	TX_SCOL		0x14
#define	TX_MCOL		0x18
#define	TX_XCOL		0x1c
#define	TX_LCOL		0x20
#define	TX_PKT_64	0x24
#define	TX_PKT_65	0x28
#define	TX_PKT_128	0x2c
#define	TX_PKT_256	0x30
#define	TX_PKT_512	0x34
#define	TX_PKT_1024	0x38
#define	TX_PKT_1519	0x3c
#define	TX_PAUSE	0x40
#define	TX_ERR		0x44
#define	TX_OCT_OK	0x60
#define	TX_OCT_BAD	0x68
#define	RX_OCT_OK	0x70
#define	RX_OCT_BAD	0x78
#define	RX_RUNT		0x80
#define	RX_OVF		0x84
#define	RX_SHORT_OK	0x88
#define	RX_SHORT_CRC	0x8c
#define	RX_UNI_OK	0x90
#define	RX_MLT_OK	0x94
#define	RX_BRD_OK	0x98
#define	RX_NORM_CRC	0x9c
#define RX_NORM_ALI	0xa0
#define	RX_LONG_OK	0xa4
#define	RX_LONG_CRC	0xa8
#define	RX_PKT_64	0xac
#define	RX_PKT_65	0xb0
#define	RX_PKT_128	0xb4
#define	RX_PKT_256	0xb8
#define	RX_PKT_512	0xbc
#define	RX_PKT_1024	0xc0
#define	RX_PKT_1519	0xc4
#define	RX_PAUSE	0xc8
#define	RX_FALS_CRS	0xcc
#define	RX_SYM_ERR	0xd0


#define	READ_COUNTER(dev,ctr)		\
		(OCTAL_MAC_REG_READ(dev,MACTOSA_ADDR_FACTOR*(CNTR_BASE + ctr))	 |	\
		OCTAL_MAC_REG_READ(dev,MACTOSA_ADDR_FACTOR*(CNTR_BASE + ctr+1))<<8 |\
		OCTAL_MAC_REG_READ(dev,MACTOSA_ADDR_FACTOR*(CNTR_BASE + ctr+2))<<16|\
		OCTAL_MAC_REG_READ(dev,MACTOSA_ADDR_FACTOR*(CNTR_BASE + ctr+3))<<24)

/* suppose to read 5 bytes */
#define	READ_COUNTER_5(dev,ctr)		\
		(OCTAL_MAC_REG_READ(dev,MACTOSA_ADDR_FACTOR *(CNTR_BASE + ctr)) |\
		OCTAL_MAC_REG_READ(dev,MACTOSA_ADDR_FACTOR*(CNTR_BASE + ctr+1))<<8 |\
		OCTAL_MAC_REG_READ(dev,MACTOSA_ADDR_FACTOR*(CNTR_BASE + ctr+2))<<16|\
		OCTAL_MAC_REG_READ(dev,MACTOSA_ADDR_FACTOR*(CNTR_BASE + ctr+3))<<24)

#define	TX_UNI_OK_CNT(dev)		READ_COUNTER(dev,TX_UNI_OK)
#define	TX_MLT_OK_CNT(dev)		READ_COUNTER(dev,TX_MLT_OK)
#define	TX_BRD_OK_CNT(dev)		READ_COUNTER(dev,TX_BRD_OK)
#define	TX_DEFER_CNT(dev)		READ_COUNTER(dev,TX_DEFER)
#define	TX_COL_CNT(dev)			READ_COUNTER(dev,TX_COL)
#define	TX_SCOL_CNT(dev)		READ_COUNTER(dev,TX_SCOL)
#define	TX_MCOL_CNT(dev)		READ_COUNTER(dev,TX_MCOL)
#define	TX_XCOL_CNT(dev)		READ_COUNTER(dev,TX_XCOL)
#define	TX_LCOL_CNT(dev)		READ_COUNTER(dev,TX_LCOL)
#define	TX_PKT_64_CNT(dev)		READ_COUNTER(dev,TX_PKT_64)
#define	TX_PKT_65_CNT(dev)		READ_COUNTER(dev,TX_PKT_65)
#define	TX_PKT_128_CNT(dev)		READ_COUNTER(dev,TX_PKT_128)
#define	TX_PKT_256_CNT(dev)		READ_COUNTER(dev,TX_PKT_256)
#define	TX_PKT_512_CNT(dev)		READ_COUNTER(dev,TX_PKT_512)
#define	TX_UNI_1024_CNT(dev)	READ_COUNTER(dev,TX_PKT_1024)
#define	TX_UNI_1519_CNT(dev)	READ_COUNTER(dev,TX_PKT_1519)
#define	TX_PAUSE_CNT(dev)		READ_COUNTER(dev,TX_PAUSE)
#define	TX_ERR_CNT(dev)			READ_COUNTER(dev,TX_ERR)

#define	TX_OCT_OK_CNT(dev)		READ_COUNTER_5(dev,TX_OCT_OK)
#define	TX_OCT_BAD_CNT(dev)		READ_COUNTER_5(dev,TX_OCT_BAD)
#define	RX_OCT_OK_CNT(dev)		READ_COUNTER_5(dev,RX_OCT_OK)
#define	RX_OCT_BAD_CNT(dev)		READ_COUNTER_5(dev,RX_OCT_BAD)

#define	RX_RUNT_CNT(dev)		READ_COUNTER(dev,RX_RUNT)
#define	RX_OVF_CNT(dev)			READ_COUNTER(dev,RX_OVF)
#define	RX_SHORT_OK_CNT(dev)	READ_COUNTER(dev,RX_SHORT_OK)
#define	RX_SHORT_CRC_CNT(dev)	READ_COUNTER(dev,RX_SHORT_CRC)
#define	RX_UNI_OK_CNT(dev)		READ_COUNTER(dev,RX_UNI_OK)
#define	RX_MLT_OK_CNT(dev)		READ_COUNTER(dev,RX_MLT_OK)
#define	RX_BRD_OK_CNT(dev)		READ_COUNTER(dev,RX_BRD_OK)
#define	RX_NORM_CRC_CNT(dev)	READ_COUNTER(dev,RX_NORM_CRC)
#define	RX_NORM_ALI_CNT(dev)	READ_COUNTER(dev,RX_NORM_ALI)
#define	RX_LONG_OK_CNT(dev)		READ_COUNTER(dev,RX_LONG_OK)
#define	RX_LONG_CRC_CNT(dev)	READ_COUNTER(dev,RX_LONG_CRC)
#define	RX_PKT_64_CNT(dev)		READ_COUNTER(dev,RX_PKT_64)
#define	RX_PKT_65_CNT(dev)		READ_COUNTER(dev,RX_PKT_65)
#define	RX_PKT_128_CNT(dev)		READ_COUNTER(dev,RX_PKT_128)
#define	RX_PKT_256_CNT(dev)		READ_COUNTER(dev,RX_PKT_256)
#define	RX_PKT_512_CNT(dev)		READ_COUNTER(dev,RX_PKT_512)
#define	RX_PKT_1024_CNT(dev)	READ_COUNTER(dev,RX_PKT_1024)
#define	RX_PKT_1519_CNT(dev)	READ_COUNTER(dev,RX_PKT_1519)
#define	RX_PAUSE_CNT(dev)		READ_COUNTER(dev,RX_PAUSE)
#define	RX_FALS_CRS_CNT(dev)	READ_COUNTER(dev,RX_FALS_CRS)
#define	RX_SYM_ERR_CNT(dev)		READ_COUNTER(dev,RX_SYM_ERR)



/*
 * IOCTL commands
 */
#define	OCTMAC_IOCTL_BASE	1000
#define	OCTMAC_IOCTL(val)	OCTMAC_IOCTL_BASE + (val)

#define	START_DEVICE		OCTMAC_IOCTL(1)
#define	TX_ONLY		0x01
#define	RX_ONLY		0x02
#define	TX_AND_RX	TX_ONLY | RX_ONLY

#define	STOP_DEVICE			OCTMAC_IOCTL(2)
#define	RESTART_DEVICE		OCTMAC_IOCTL(3)
#define	RESET_DEVICE		OCTMAC_IOCTL(4)

#define	CONFIG_DEVICE		OCTMAC_IOCTL(6)
#define	START_SELF_TEST		OCTMAC_IOCTL(7)
#define	EXTERNAL_LOOPBACK	0x1
#define	INTERNAL_LOOPBACK	0x2

#define	STOP_SELF_TEST		OCTMAC_IOCTL(8)
#define	GET_SNMP_STATS		OCTMAC_IOCTL(9)
#define	GET_RMON_HOST_STATS	OCTMAC_IOCTL(10)
#define	GET_RMON_ETH_STATS	OCTMAC_IOCTL(11)
#define	RESET_STATS			OCTMAC_IOCTL(12)
#define	GET_LOCAL_FLAGS		OCTMAC_IOCTL(13)
#define	GET_MAC_ADDR		OCTMAC_IOCTL(14)
#define	GET_DEVICE_ID		OCTMAC_IOCTL(15)
#define	GET_REVISION_ID		OCTMAC_IOCTL(16)

#define START_TX_ONLY   OCTMAC_IOCTL(17)
#define START_RX_ONLY   OCTMAC_IOCTL(18)
#define STOP_TX_ONLY    OCTMAC_IOCTL(19)
#define STOP_RX_ONLY    OCTMAC_IOCTL(20)
#define GET_PORT_CTR    OCTMAC_IOCTL(21)  //added for test
#define GET_OCT_CSR     OCTMAC_IOCTL(22)  //sdded for test


/*
 * UTILITY MACROS
 */
#define DELAY(cnt)			\
		{	volatile int i=(1000 * cnt); while (i-->0); }
#define INODE_TO_PORT(inode)	(MINOR((inode)->i_rdev) - minorStart)
			

/***********************************************
 * DATA STRUCTURES 
 ***********************************************/

#define MAX_OCTMAC_NAMELEN	32
#define MAX_HWARE_ADDR_LEN	6	/* ethernet address size */

/*
 * STATUS FLAG IN USER CONTROL BLOCK / LOCAL FLAGS
 *
 *		status			bit			comment
 *		------			---			-------
 */
#define	LINK_STATUS		0x01	/* set => link down, else link OK */
#define	TX_ERROR		0x02	/* set => tx error latch */
#define	RX_ERROR		0x04	/* set => rx error latch */
#define	CNTR_OVERFLOW	0x08	/* set => counter overflow */
#define	PORT_STOP		0x10	/* set => port stopped */
#if 0
#define	IFF_PROMISC		0x20	/* set => in promisc mode */
#define	IFF_MULTICAST	0x40	/* set => can do muticast stuff */
#endif
#define	SER_MODE_SYM	0x80	/* set => SYM mode */

#ifdef __KERNEL__	
typedef struct octMacDevDesc
{
	struct miscdevice	sysDesc;	
    volatile unsigned char	*pRegBase;/* register set base address */
	unsigned char	mac[MAX_HWARE_ADDR_LEN];/* 	6 bytes */
	char	name[MAX_OCTMAC_NAMELEN];
	int		localFlags;
#if	0
	unsigned int	*pFlag;		/* pointer to status flag in UCB */
#endif
} tOctMacDevDesc;

#endif //#ifdef __KERNEL__	

/*
 * DEVICE CONFIGURATION PARAMETERS
 */
#define	HALF_DUPLEX			0
#define	FULL_DUPLEX			1

#define	FIFO_BUS_WIDTH_32	0
#define	FIFO_BUS_WIDTH_64	1
#define	FIFO_LITTLE_ENDIAN	0
#define	FIFO_BIG_ENDIAN		1

#define	HDR_READY_ENABLE	0
#define	HDR_READY_DISABLE	1

#define	MANY_PKT_MODE		0
#define	SINGLE_PKT_MODE		1

#define	XON_ENABLE		0
#define	XON_DISABLE		1

#define	FLOW_CNTL_MODE_DISABLE	0
#define	FLOW_CNTL_MODE_ENABLE	1

#define	TX_CRC_APPEND_ENABLE	0
#define	TX_CRC_APPEND_DISABLE	1

#define	TX_PAD_APPEND_ENABLE	0
#define	TX_PAD_APPEND_DISABLE	1

#define	PKT_TX_TSHD_12		1
#define	PKT_TX_TSHD_20		2
#define	PKT_TX_TSHD_28		3
#define	PKT_TX_TSHD_36		4
#define	PKT_TX_TSHD_44		5
#define	PKT_TX_TSHD_52		6
#define	PKT_TX_TSHD_60		7
#define	PKT_TX_TSHD_68		8
#define	PKT_TX_TSHD_76		9
#define	PKT_TX_TSHD_84		10
#define	PKT_TX_TSHD_92		11
#define	PKT_TX_TSHD_100		12
#define	PKT_TX_TSHD_108		13
#define	PKT_TX_TSHD_116		14
#define	PKT_TX_TSHD_124		15

#define	RX_CRC_KEEP		0
#define	RX_CRC_REMOVE	1

#define	HDR_REPLAY_DISABLE	0
#define	HDR_REPLAY_ENABLE	1

#define	MIN_HDR_REPLAY_SIZE	4
#define	MAX_HDR_REPLAY_SIZE	48

#define	MII_MODE	0x0
#define	SYM_MODE	0x1

/*
 * Before sending configuration information, the whole structure
 * is to be zeroed out. (So default values upon reset will be present).
 * But, MAC address has to be set always.
 */

typedef struct octMacConfig
{
	char	duplexMode;		/* Full or half */
	char    busWidth;		/* 64 or 32 */
    char    endianness;		/* big or little */
	char	rxHdrRdyEnable;	/* TRUE -> signal when pkt hdr is in FIFO. */
	char	txPktMode;		/* load single / multiple pkts into tx FIFO */	
	char	xonMode;
	char	flwCtrl;
	char	txCrcAppend;	/* pad CRC at end of tx packet */
	char	txPadAppend;	/* make min pkt size 64 */
	int 	txPktTshd;		/* tx FIFO threshold */
	char	rxCrcRemove;	/* remove CRC from rx pkt */
	char	rxHdrReplay;	/* transfer header twice on rx */
	int 	rxHdrReplaySize;/* size of header for replay */
	int 	txPauseTime;	/* remote node holds tx for this period */
	int 	maxRxPktSize;
	char	serMode;		/* MII / SYM mode */
    int 	txTshd;			/* min space in FIFO to load next pkt */
    int 	rxTshd;			/* min space in FIFO to rx next pkt */
	char	mac[MAX_HWARE_ADDR_LEN];	/* Ethernet address */
} tOctMacConfig;



typedef struct octMacSnmpStats
{
	unsigned int FramesTransmittedOK;
	unsigned int SingleCollisionFrames;
	unsigned int MultipleCollisionFrames;
	unsigned int FramesReceivedOK;
	unsigned int FramesCheckSequenceErrors;
	unsigned int AlignmentErrors;
	unsigned int OctetsTransmittedOK;
	unsigned int FramesWithDeferredXmissions;
	unsigned int LateCollisions;
	unsigned int FramesAbortedDueToXSColls;
	unsigned int OctetsReceivedOK;
	unsigned int FrameTooLongErrors;
	unsigned int MulticastFramesXmittedOK;
	unsigned int BroadcastFramesReceivedOK;
	unsigned int MulticastFramesReceivedOK;
	unsigned int BroadcastFramesXmittedOK;
	unsigned int PauseFramesTransmitted;
	unsigned int PauseFramesReceived;
} tOctMacSnmpStats;


typedef struct octMacRmonStatGrp
{
	unsigned int dropEvents;
	unsigned int octets;
	unsigned int pkts;
	unsigned int broadcastPkts;
	unsigned int multicastPkts;
	unsigned int CRCAlignErrors;
	unsigned int undersizePkts;
	unsigned int oversizePkts;
	unsigned int fragments;
	unsigned int jabber;
	unsigned int collisions;
	unsigned int pkts64Octets;
	unsigned int pkts65to127Octets;
	unsigned int pkts128to255Octets;
 	unsigned int pkts256to511Octets;
	unsigned int pkts512to1023Octets;
	unsigned int pkts1024to1518Octets;
} tOctMacRmonStatGrp;

typedef	struct	octMacRmonHostGrp
{
	unsigned int hostInPkts;
	unsigned int hostOutPkts;
	unsigned int hostInOctets;
	unsigned int hostOutOctets;
	unsigned int hostOutErrors;
	unsigned int hostOutBroadcastPkts;
	unsigned int hostOutMulticastPkts;
} tOctMacRmonHostGrp;

typedef	struct	octMacCsrGrp
{
	unsigned char chip_int; 	
        unsigned char int_stt; 	
	unsigned char int_en;  
	unsigned char txmt_stt;
	unsigned char recv_stt;
	unsigned char port_ctr;
	unsigned char dev_id;
        unsigned char rev_id;
	unsigned char ser_com;
	unsigned char ffo_tshd;
	unsigned char ffo_bus;
	unsigned char tx_param;
	unsigned char tx_err_mod;
	unsigned char tx_tshd_boff;
	unsigned char rx_param;	
	unsigned char rx_filt_mod;
	unsigned short pause_time;
        unsigned short pkt_max_sz;
	unsigned char ser_mod;  
	unsigned char lnk_stt;
	unsigned long long int phy_addr;
        unsigned short ipg;
} tOctMacCsrGrp;

/*
 * FUNCTION PROTOTYPES
 */

extern	int	octMacInit(void);
extern	int	octMacClean(void);


#endif	OCTAL_MAC_DRV_H
